/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

namespace Nuvola{

/**
 * Window with embedded WebKit Inspector used to examine pages loaded in WebViews.
 */
public class InspectorWindow: Gtk.Window{
	private WebKit.WebInspector inspector;
	private WebKit.WebView inspector_view;
	
	/**
	 * Creates new Inspector Window.
	 * 
	 * Memory management: The window is not destroyed on delete-event. If you want to destroy it
	 * before end of application life cycle, you have to do it yourselves.
	 * 
	 * @param view	WebKit view to inspect
	 */
	public InspectorWindow(WebKit.WebView view){
		inspector = view.get_inspector();
		inspector.inspect_web_view.connect(on_inspect_web_view);
		inspector.show_window.connect(on_inspector_show);
		set_default_size(600, 400);
		/// title of window
		title = _("WebKit Inspector Window - Nuvola Player");
	}
	
	private unowned WebKit.WebView on_inspect_web_view(WebKit.WebView view){
		inspector_view = new WebKit.WebView();
		var scroll = new Gtk.ScrolledWindow(null, null);
		scroll.add(inspector_view);
		add(scroll);
		scroll.show_all();
		return inspector_view;
	}
	
	private bool on_inspector_show(){
		present();
		return false;
	}
	
	public override bool delete_event(Gdk.EventAny event){
		/* Do not destroy window. It would case destroying of this.inspector and the webview
		 * will not be introspectable. */
		hide();
		return true;
	}
}

} // namespace Nuvola
